@@ -1,3 +1,4 @@
+import queue
 from unittest import TestCase
 import time
 import string
@@ -14,11 +15,11 @@ class TestSimpleThreadsRunner(TestCase):
         time.sleep(1)
 
     def test_01_run_threads(self):
-        sr = SimpleThreadsRunner(5, self.n_print)
-        sr.run_threads(iter_data=self.actions)
+        sr = SimpleThreadsRunner(self.n_print)
+        # LifoQueue
+        sr._queue = queue.LifoQueue()
+        sr.run_threads(5, iter_data=self.actions)
 
     def test_02_batch_run_threads(self):
-        sr = SimpleThreadsRunner(5, self.n_print)
-        sr.run_threads(iter_data=self.actions, batch_size=10)
-
-
+        sr = SimpleThreadsRunner(self.n_print)
+        sr.run_threads(5, iter_data=self.actions, batch_size=10)
